Get Usage
/usage
Request
-
@baseType: string
The base type of Usage to return.
-
@schemaLocation: string
The schema location of Usage to return.
-
@type: string
The type of Usage to return.Example:
Usage -
appliedCustomerBillingRate.id: string
The applied customer billing rate identifier.Example:
0.0.0.1+-item-misc+308426205730877776 -
billId: string
The bill identifier.Example:
0.0.0.1+-bill+363982329259147952 -
billStructure.billInfoId: string
The bill information identifier.Example:
0.0.0.1+-billinfo+180320 -
billStructure.billInfoName: string
The bill information name.Example:
BillStructure-8 -
billStructure.id: string
The bill structure ID or external identifier.Examples
-
billingAccount.id: string
The billing account identifier.Examples
-
description: string
The usage description.
-
endTime: string(date-time)
The usage end date and time.Example:
2018-01-01T08:00:00.00Z -
id: string
The Usage identifier.Examples
-
limit: integer
The requested number of resources to include in the response.Example:
2 -
networkId: string
The network session identifier.
-
offset: integer
The requested index specifies the first resource to include in the response.Example:
2 -
resourceId: string
The resource identifier.Example:
USD -
service.alias.name: string
The service alias name.
-
service.id: string
The service ID or external identifier.Examples
-
service.login: string
The service login.
-
taxExcludedAmount: number(float)
The tax-excluded amount.
-
taxIncludedAmount: number(float)
The tax-included amount.
-
usageDate: string(date-time)
The usage start date and time.Example:
2018-01-01T08:00:00.00Z -
usageType: string
The type of usage.
There's no request body for this operation.
Back to TopResponse
- application/json;charset=utf-8
200 Response
-
X-Result-Count:
The actual number of items returned in the response body.
-
X-Total-Count:
The total number of items that match the criteria.
array-
Array of:
object Usage
An occurrence of employing a Product, Service, or Resource for its intended purpose, which is of interest to the business and can have charges applied to it. It is comprised of characteristics, which represent attributes of usage.
object-
@baseType: string
When sub-classing, this defines the super-class.
-
@schemaLocation: string
(uri)
A URI to a JSON-Schema file that defines additional attributes and relationships.
-
@type: string
When sub-classing, this defines the sub-class Extensible name.
-
adjustedAmount: object
Money
Represents a monetary amount.
-
appliedCustomerBillingRate: object
appliedCustomerBillingRate
The applied customer billing rate associated with the usage.
-
bill: object
bill
The bill associated with the usage.
-
billingAccount: object
billingAccount
The billing account associated with the usage.
-
billStructure: object
billStructure
The bill structure associated with the usage.
-
bytesIn: integer
The number of incoming bytes.
-
bytesOut: integer
The number of outgoing bytes.
-
calledToNumber: string
The called telephone number.
-
cycleEnd: string
(date-time)
The end date and time of the cycle.
-
cycleStart: string
(date-time)
The start date and time of the cycle.
-
description: string
The description of the usage.Example:
Voicemail Retrieval -
discount: object
Money
Represents a monetary amount.
-
disputedAmount: object
Money
Represents a monetary amount.
-
effectiveDate: string
(date-time)
The date and time when the usage became effective.
-
endTime: string
(date-time)
The end date and time of the usage.
-
href: string
(uri)
The hyperlink reference.
-
id: string
The unique identifier.
-
nonCurrencyDetails: array
nonCurrencyDetails
The rated details for non-currency resources.
-
quantity: number
(double)
The consumed quantity.
-
ratedProductUsage: array
ratedProductUsage
-
remainingAmount: object
Money
Represents a monetary amount.
-
rumName: string
The rating unit of measure name.
-
service: object
service
The service associated with the usage.
-
settledDisputeAmount: object
Money
Represents a monetary amount.
-
taxAmount: object
Money
Represents a monetary amount.
-
usageDate: string
(date-time)
The date of the usage.Example:
2020-09-21T09:13:16-07:00 -
usageType: string
The type of usage.
object-
unit: string
The currency's ISO 4217 three-letter code.
-
value: number
(double)
A signed floating-point number whose sign depends on the API context.
object-
id: string
The unique identifier.
object-
id: string
The unique identifier.
object-
id: string
The unique identifier.
object-
id: string
The unique identifier.
array-
Array of:
object NonCurrencyDetail
Rated details for a non-currency resource.
array-
Array of:
object RatedProductUsage
An occurrence of employing a product for its intended purpose with all rating details.
object-
id: string
The unique identifier.
object-
originalNetAmount: number
(double)
The original net amount.
-
priorAdjustment: number
(double)
The prior adjustment amount.
-
priorDisputes: number
(double)
The prior disputed amount.
-
resourceName: string
The resource name.
object-
taxCode: string
The tax code.
-
taxExcludedAmount: object
Money
Represents a monetary amount.
-
taxIncludedAmount: object
Money
Represents a monetary amount.
-
taxRate: number
(float)
The tax rate.
400 Response
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Error-allOf[1]
object-
@baseType: string
The superclass.
-
@schemaLocation: string
The URI of a JSON Schema file that defines additional attributes and relationships.
-
@type(required): string
The subclass Extensible name.
object-
code(required): string
The application-specific error detail defined by the API or a common list.
-
message: string
Provides error details and corrective actions for a client user.
-
reason(required): string
Explains the error to a client user.
-
referenceError: string
The URI of documentation that describes the error.
-
status: string
The HTTP error code extension.
401 Response
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Error-allOf[1]
object-
@baseType: string
The superclass.
-
@schemaLocation: string
The URI of a JSON Schema file that defines additional attributes and relationships.
-
@type(required): string
The subclass Extensible name.
object-
code(required): string
The application-specific error detail defined by the API or a common list.
-
message: string
Provides error details and corrective actions for a client user.
-
reason(required): string
Explains the error to a client user.
-
referenceError: string
The URI of documentation that describes the error.
-
status: string
The HTTP error code extension.
403 Response
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Error-allOf[1]
object-
@baseType: string
The superclass.
-
@schemaLocation: string
The URI of a JSON Schema file that defines additional attributes and relationships.
-
@type(required): string
The subclass Extensible name.
object-
code(required): string
The application-specific error detail defined by the API or a common list.
-
message: string
Provides error details and corrective actions for a client user.
-
reason(required): string
Explains the error to a client user.
-
referenceError: string
The URI of documentation that describes the error.
-
status: string
The HTTP error code extension.
404 Response
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Error-allOf[1]
object-
@baseType: string
The superclass.
-
@schemaLocation: string
The URI of a JSON Schema file that defines additional attributes and relationships.
-
@type(required): string
The subclass Extensible name.
object-
code(required): string
The application-specific error detail defined by the API or a common list.
-
message: string
Provides error details and corrective actions for a client user.
-
reason(required): string
Explains the error to a client user.
-
referenceError: string
The URI of documentation that describes the error.
-
status: string
The HTTP error code extension.
405 Response
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Error-allOf[1]
object-
@baseType: string
The superclass.
-
@schemaLocation: string
The URI of a JSON Schema file that defines additional attributes and relationships.
-
@type(required): string
The subclass Extensible name.
object-
code(required): string
The application-specific error detail defined by the API or a common list.
-
message: string
Provides error details and corrective actions for a client user.
-
reason(required): string
Explains the error to a client user.
-
referenceError: string
The URI of documentation that describes the error.
-
status: string
The HTTP error code extension.
409 Response
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Error-allOf[1]
object-
@baseType: string
The superclass.
-
@schemaLocation: string
The URI of a JSON Schema file that defines additional attributes and relationships.
-
@type(required): string
The subclass Extensible name.
object-
code(required): string
The application-specific error detail defined by the API or a common list.
-
message: string
Provides error details and corrective actions for a client user.
-
reason(required): string
Explains the error to a client user.
-
referenceError: string
The URI of documentation that describes the error.
-
status: string
The HTTP error code extension.
500 Response
-
object
Extensible
Represents a base extensible schema for TM Forum Open APIs. The entity must include @type.
-
object
Error-allOf[1]
object-
@baseType: string
The superclass.
-
@schemaLocation: string
The URI of a JSON Schema file that defines additional attributes and relationships.
-
@type(required): string
The subclass Extensible name.
object-
code(required): string
The application-specific error detail defined by the API or a common list.
-
message: string
Provides error details and corrective actions for a client user.
-
reason(required): string
Explains the error to a client user.
-
referenceError: string
The URI of documentation that describes the error.
-
status: string
The HTTP error code extension.
Examples
Get Usage with a Result Limit
The following examples show how to get usage data by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
The request uses the limit query parameter to limit the results.
curl -X GET 'http://host:port/brm/usageManagement/version/usage?limit=2'
Response Body
The following example shows the contents of the response body in JSON format.
[
{
"@baseType": "Usage",
"@type": "Usage",
"id": "0.0.0.1+-event-billing-product-fee-cycle-cycle_forward_monthly+326088760519522593",
"href": "http://host:port/brm/usageManagement/version/usage/0.0.0.1+-event-billing-product-fee-cycle-cycle_forward_monthly+326088760519522593",
"usageDate": "2025-08-14T00:00:00-07:00",
"usageType": "EventBillingProductFeeCycleCycle_forward_monthly",
"status": "rated",
"usageCharacteristic": [],
"relatedParty": [],
"ratedProductUsage": [
{
"ratingDate": "2025-08-14T00:00:00-07:00",
"usageRatingTag": "Rate 1",
"taxExcludedRatingAmount": {
"unit": "USD",
"value": 20.0
},
"taxIncludedRatingAmount": {
"unit": "USD",
"value": 20.0
},
"taxRate": 0.0
}
]
},
{
"@baseType": "Usage",
"@type": "Usage",
"id": "0.0.0.1+-event-billing-product-fee-cycle-cycle_forward_monthly+326088760519524129",
"href": "http://host:port/brm/usageManagement/version/usage/0.0.0.1+-event-billing-product-fee-cycle-cycle_forward_monthly+326088760519524129",
"usageDate": "2025-09-14T00:00:00-07:00",
"usageType": "EventBillingProductFeeCycleCycle_forward_monthly",
"status": "rated",
"usageCharacteristic": [],
"relatedParty": [],
"ratedProductUsage": [
{
"ratingDate": "2025-09-14T00:00:00-07:00",
"usageRatingTag": "Rate 1",
"taxExcludedRatingAmount": {
"unit": "USD",
"value": 40.0
},
"taxIncludedRatingAmount": {
"unit": "USD",
"value": 40.0
},
"taxRate": 0.0
}
]
}
]
Get Usage by Date Range
The following example retrieves usage records of type Usage within an inclusive usageDate range for a bill structure. The limit query parameter limits the response to two records.
curl -X GET 'http://host:port/brm/usageManagement/v4/usage?limit=2&usageDate.gte=2018-01-01T08:00:00%2B00:00&usageDate.lte=2026-12-01T08:00:00%2B05:00&billStructure.id=billing-account-strucuture-post-4'
Response Body
The following example shows the contents of the response body in JSON format.
[
{
"@type": "Usage",
"billStructure": {
"id": "billing-account-strucuture-post-4"
},
"description": "Event Settlement",
"endTime": "2026-10-09T03:40:46.00Z",
"id": "0.0.0.1+-event-billing-settlement-event+364756385445133691",
"href": "http://localhost:9090/brm/usageManagement/v5/usage/0.0.0.1+-event-billing-settlement-event+364756385445133691",
"taxAmount": {
"unit": "EUR",
"value": 0
},
"remainingAmount": {
"unit": "EUR",
"value": 46.548
},
"settledDisputeAmount": {
"unit": "EUR",
"value": 3
},
"discount": {
"unit": "EUR",
"value": 0
},
"billingAccount": {
"id": "0.0.0.1-158699"
},
"service": {
"id": "service-635"
},
"usageType": "/event/billing/settlement/event",
"cycleEnd": "",
"effectiveDate": "",
"rumName": "",
"@baseType": "Usage",
"appliedCustomerBillingRate": {
"id": "0.0.0.1+-item-settlement+364756385445131643"
},
"cycleStart": "",
"quantity": 0,
"@SchemaLocation": "",
"ratedProductUsage": [
{
"taxIncludedAmount": {
"unit": "EUR",
"value": 43.548
},
"taxExcludedAmount": {
"unit": "EUR",
"value": 43.548
},
"taxCode": "VAT",
"taxRate": 0
}
],
"nonCurrencyDetails": [
{
"resourceName": "YES",
"originalNetAmount": -3135.5
}
],
"usageDate": "2026-10-09T03:40:46.00Z"
},
{
"@type": "Usage",
"billStructure": {
"id": "billing-account-strucuture-post-4"
},
"description": "Event Dispute",
"endTime": "2026-10-09T03:17:09.00Z",
"id": "0.0.0.1+-event-billing-dispute-event+364756385445132411",
"href": "http://localhost:9090/brm/usageManagement/v5/usage/0.0.0.1+-event-billing-dispute-event+364756385445132411",
"taxAmount": {
"unit": "EUR",
"value": 0
},
"remainingAmount": {
"unit": "EUR",
"value": 46.548
},
"settledDisputeAmount": {
"unit": "EUR",
"value": 3
},
"discount": {
"unit": "EUR",
"value": 0
},
"billingAccount": {
"id": "0.0.0.1-158699"
},
"service": {
"id": "service-635"
},
"usageType": "/event/billing/dispute/event",
"cycleEnd": "",
"effectiveDate": "",
"rumName": "",
"@baseType": "Usage",
"appliedCustomerBillingRate": {
"id": "0.0.0.1+-item-dispute+364756385445130363"
},
"cycleStart": "",
"quantity": 0,
"@SchemaLocation": "",
"ratedProductUsage": [
{
"taxIncludedAmount": {
"unit": "EUR",
"value": 43.548
},
"taxExcludedAmount": {
"unit": "EUR",
"value": 43.548
},
"taxCode": "VAT",
"taxRate": 0
}
],
"nonCurrencyDetails": [
{
"resourceName": "YES",
"originalNetAmount": -3135.5
}
],
"usageDate": "2026-10-09T03:17:09.00Z"
}
]
Get Usage by Service ID
The following example retrieves usage records using a service POID in the service.id query parameter.
curl -X GET 'http://host:port/brm/usageManagement/v4/usage?service.id=0.0.0.1+-service-telco-gsm-telephony+545925'
Response Body
The following example shows the contents of the response body in JSON format.
[
{
"@type": "Usage",
"billStructure": {
"id": "0.0.0.1+-bill_structure+173320"
},
"description": "Set Password",
"endTime": "2018-01-01T08:00:00Z",
"id": "0.0.0.1+-event-customer-password+308426205730874033",
"href": "https://localhost:8089/brm/usageManagement/v5/usage/0.0.0.1+-event-customer-password+308426205730874033",
"billingAccount": {
"id": "0.0.0.1+-account+175112"
},
"service": {
"id": "0.0.0.1+-service-ip+173233"
},
"usageType": "/event/customer/password",
"cycleEnd": "",
"effectiveDate": "",
"rumName": "",
"@baseType": "Usage",
"appliedCustomerBillingRate": {
"id": "0.0.0.0++0"
},
"cycleStart": "",
"quantity": 0.0,
"@SchemaLocation": "",
"createdTime": "2018-01-01T08:00:00Z",
"usageDate": "2018-01-01T08:00:00Z"
},
{
"@type": "Usage",
"billStructure": {
"id": "0.0.0.1+-bill_structure+173320"
},
"description": "Cycle Forward Fees (srvc): Product 1a - Internet Access",
"endTime": "2018-01-01T08:00:00Z",
"id": "0.0.0.1+-event-billing-product-fee-cycle-cycle_forward_monthly+308426205730873777",
"href": "https://localhost:8089/brm/usageManagement/v5/usage/0.0.0.1+-event-billing-product-fee-cycle-cycle_forward_monthly+308426205730873777",
"billingAccount": {
"id": "0.0.0.1+-account+175112"
},
"service": {
"id": "0.0.0.1+-service-ip+173233"
},
"usageType": "/event/billing/product/fee/cycle/cycle_forward_monthly",
"cycleEnd": "2018-02-03T08:00:00Z",
"effectiveDate": "",
"rumName": "Occurrence",
"@baseType": "Usage",
"appliedCustomerBillingRate": {
"id": "0.0.0.1+-item-cycle_forward+308426205730877105"
},
"cycleStart": "2018-01-01T08:00:00Z",
"quantity": 1.0,
"@SchemaLocation": "",
"createdTime": "2018-01-01T08:00:00Z",
"usageDate": "2018-01-01T08:00:00Z",
"taxAmount": {
"unit": "USD",
"value": 0.0
},
"remainingAmount": {
"unit": "USD",
"value": 10.59
},
"discount": {
"unit": "USD",
"value": 0.0
},
"bill": {
"id": "0.0.0.1+-bill+308426205730875505"
},
"ratedProductUsage": [
{
"taxIncludedAmount": {
"unit": "USD",
"value": 10.59
},
"taxExcludedAmount": {
"unit": "USD",
"value": 10.59
}
}
]
},
{
"@type": "Usage",
"billStructure": {
"id": "0.0.0.1+-bill_structure+173320"
},
"description": "Event Adjustment",
"endTime": "2018-01-01T08:00:00Z",
"id": "0.0.0.1+-event-billing-adjustment-event+308426205730878738",
"href": "https://localhost:8089/brm/usageManagement/v5/usage/0.0.0.1+-event-billing-adjustment-event+308426205730878738",
"billingAccount": {
"id": "0.0.0.1+-account+175112"
},
"service": {
"id": "0.0.0.1+-service-ip+173233"
},
"usageType": "/event/billing/adjustment/event",
"cycleEnd": "",
"effectiveDate": "",
"rumName": "",
"@baseType": "Usage",
"appliedCustomerBillingRate": {
"id": "0.0.0.1+-item-adjustment+308426205730879762"
},
"cycleStart": "",
"quantity": 0.0,
"@SchemaLocation": "",
"createdTime": "2018-01-01T08:00:00Z",
"usageDate": "2018-01-01T08:00:00Z",
"taxAmount": {
"unit": "USD",
"value": 0.0
},
"remainingAmount": {
"unit": "USD",
"value": -0.5
},
"discount": {
"unit": "USD",
"value": 0.0
},
"ratedProductUsage": [
{
"taxIncludedAmount": {
"unit": "USD",
"value": -0.5
},
"taxExcludedAmount": {
"unit": "USD",
"value": -0.5
}
}
]
},
{
"@type": "Usage",
"billStructure": {
"id": "0.0.0.1+-bill_structure+173320"
},
"description": "Set Status (srvc)",
"endTime": "2018-01-01T08:00:00Z",
"id": "0.0.0.1+-event-customer-status+308426205730876081",
"href": "https://localhost:8089/brm/usageManagement/v5/usage/0.0.0.1+-event-customer-status+308426205730876081",
"billingAccount": {
"id": "0.0.0.1+-account+175112"
},
"service": {
"id": "0.0.0.1+-service-ip+173233"
},
"usageType": "/event/customer/status",
"cycleEnd": "",
"effectiveDate": "",
"rumName": "",
"@baseType": "Usage",
"appliedCustomerBillingRate": {
"id": "0.0.0.0++0"
},
"cycleStart": "",
"quantity": 0.0,
"@SchemaLocation": "",
"createdTime": "2018-01-01T08:00:00Z",
"usageDate": "2018-01-01T08:00:00Z"
},
{
"@type": "Usage",
"billStructure": {
"id": "0.0.0.1+-bill_structure+173320"
},
"description": "Purchase Product (srvc): Product 1a - Internet Access",
"endTime": "2018-01-01T08:00:00Z",
"id": "0.0.0.1+-event-billing-product-action-purchase+17592186217905",
"href": "https://localhost:8089/brm/usageManagement/v5/usage/0.0.0.1+-event-billing-product-action-purchase+17592186217905",
"billingAccount": {
"id": "0.0.0.1+-account+175112"
},
"service": {
"id": "0.0.0.1+-service-ip+173233"
},
"usageType": "/event/billing/product/action/purchase",
"cycleEnd": "",
"effectiveDate": "",
"rumName": "",
"@baseType": "Usage",
"appliedCustomerBillingRate": {
"id": "0.0.0.0++0"
},
"cycleStart": "",
"quantity": 0.0,
"@SchemaLocation": "",
"createdTime": "2018-01-01T08:00:00Z",
"usageDate": "2018-01-01T08:00:00Z"
},
{
"@type": "Usage",
"billStructure": {
"id": "0.0.0.1+-bill_structure+173320"
},
"description": "Set Login",
"endTime": "2018-01-01T08:00:00Z",
"id": "0.0.0.1+-event-customer-login+308426205730876593",
"href": "https://localhost:8089/brm/usageManagement/v5/usage/0.0.0.1+-event-customer-login+308426205730876593",
"billingAccount": {
"id": "0.0.0.1+-account+175112"
},
"service": {
"id": "0.0.0.1+-service-ip+173233"
},
"usageType": "/event/customer/login",
"cycleEnd": "",
"effectiveDate": "",
"rumName": "",
"@baseType": "Usage",
"appliedCustomerBillingRate": {
"id": "0.0.0.0++0"
},
"cycleStart": "",
"quantity": 0.0,
"@SchemaLocation": "",
"createdTime": "2018-01-01T08:00:00Z",
"usageDate": "2018-01-01T08:00:00Z"
}
]
Get Usage by Amount Range
The following example searches for usage records with a tax-excluded amount from 1000 through 10000, inclusive, for the USD resource.
curl -X GET 'http://host:port/brm/usageManagement/v4/usage?taxExcludedAmount.gte=1000&taxExcludedAmount.lte=10000&resourceId=USD'
Response Body
The following example shows the contents of the response body in JSON format.
{
"@type": "Usage",
"billStructure": {
"id": "0.0.0.1+-bill_structure+173320"
},
"description": "Cycle Forward Fees (srvc): Product 1a - Internet Access",
"endTime": "2018-01-01T08:00:00Z",
"id": "0.0.0.1+-event-billing-product-fee-cycle-cycle_forward_monthly+308426205730873777",
"href": "https://localhost:8089/brm/usageManagement/v5/usage/0.0.0.1+-event-billing-product-fee-cycle-cycle_forward_monthly+308426205730873777",
"billingAccount": {
"id": "0.0.0.1+-account+175112"
},
"service": {
"id": "0.0.0.1+-service-ip+173233"
},
"usageType": "/event/billing/product/fee/cycle/cycle_forward_monthly",
"cycleEnd": "2018-02-03T08:00:00Z",
"effectiveDate": "",
"rumName": "Occurrence",
"@baseType": "Usage",
"appliedCustomerBillingRate": {
"id": "0.0.0.1+-item-cycle_forward+308426205730877105"
},
"cycleStart": "2018-01-01T08:00:00Z",
"quantity": 1.0,
"@SchemaLocation": "",
"createdTime": "2018-01-01T08:00:00Z",
"usageDate": "2018-01-01T08:00:00Z",
"taxAmount": {
"unit": "USD",
"value": 0.0
},
"remainingAmount": {
"unit": "USD",
"value": 10.59
},
"discount": {
"unit": "USD",
"value": 0.0
},
"bill": {
"id": "0.0.0.1+-bill+308426205730875505"
},
"ratedProductUsage": [
{
"taxIncludedAmount": {
"unit": "USD",
"value": 10.59
},
"taxExcludedAmount": {
"unit": "USD",
"value": 10.59
}
}
]
}
Get Usage by Bill Item
The following example retrieves usage records using a bill item POID in the appliedCustomerBillingRate.id query parameter. This parameter corresponds to PIN_FLD_ITEM_OBJ in BRM.
curl -X GET 'http://host:port/brm/usageManagement/v4/usage?appliedCustomerBillingRate.id=0.0.0.1+-item-misc+308426205730872011'
Response Body
The following example shows the contents of the response body in JSON format.
{
"@type": "Usage",
"billStructure": {
"id": "0.0.0.1+-bill_structure+173320"
},
"description": "Cycle Forward Fees (srvc): Product 1a - Internet Access",
"endTime": "2018-01-01T08:00:00Z",
"id": "0.0.0.1+-event-billing-product-fee-cycle-cycle_forward_monthly+308426205730873777",
"href": "https://localhost:8089/brm/usageManagement/v5/usage/0.0.0.1+-event-billing-product-fee-cycle-cycle_forward_monthly+308426205730873777",
"billingAccount": {
"id": "0.0.0.1+-account+175112"
},
"service": {
"id": "0.0.0.1+-service-ip+173233"
},
"usageType": "/event/billing/product/fee/cycle/cycle_forward_monthly",
"cycleEnd": "2018-02-03T08:00:00Z",
"effectiveDate": "",
"rumName": "Occurrence",
"@baseType": "Usage",
"appliedCustomerBillingRate": {
"id": "0.0.0.1+-item-cycle_forward+308426205730877105"
},
"cycleStart": "2018-01-01T08:00:00Z",
"quantity": 1.0,
"@SchemaLocation": "",
"createdTime": "2018-01-01T08:00:00Z",
"usageDate": "2018-01-01T08:00:00Z",
"taxAmount": {
"unit": "USD",
"value": 0.0
},
"remainingAmount": {
"unit": "USD",
"value": 10.59
},
"discount": {
"unit": "USD",
"value": 0.0
},
"bill": {
"id": "0.0.0.1+-bill+308426205730875505"
},
"ratedProductUsage": [
{
"taxIncludedAmount": {
"unit": "USD",
"value": 10.59
},
"taxExcludedAmount": {
"unit": "USD",
"value": 10.59
}
}
]
}
Get Usage with Non-Currency Details
The following example retrieves usage records from the collection endpoint. The response illustrates non-currency details.
curl -X GET 'http://host:port/brm/usageManagement/v4/usage'
Response Body
The following example shows the contents of the response body in JSON format.
[
{
"@type": "Usage",
"billStructure": {
"id": "billing-account-strucuture-post-4"
},
"description": "Event Adjustment",
"endTime": "2026-10-07T08:41:42.00Z",
"id": "0.0.0.1+-event-billing-adjustment-event+364738793259055330",
"href": "http://localhost:9090/brm/usageManagement/v5/usage/0.0.0.1+-event-billing-adjustment-event+364738793259055330",
"taxAmount": {
"unit": "EUR",
"value": 0.0
},
"remainingAmount": {
"unit": "EUR",
"value": 43.548
},
"discount": {
"unit": "EUR",
"value": 0.0
},
"billingAccount": {
"id": "0.0.0.1-158699"
},
"service": {
"id": "service-635"
},
"usageType": "/event/billing/adjustment/event",
"cycleEnd": "",
"effectiveDate": "",
"rumName": "",
"@baseType": "Usage",
"appliedCustomerBillingRate": {
"id": "0.0.0.1+-item-adjustment+364738793259053282"
},
"cycleStart": "",
"quantity": 0.0,
"@SchemaLocation": "",
"ratedProductUsage": [
{
"taxIncludedAmount": {
"unit": "EUR",
"value": 43.548
},
"taxExcludedAmount": {
"unit": "EUR",
"value": 43.548
},
"taxCode": "VAT",
"taxRate": 0.0
}
],
"nonCurrencyDetails": [
{
"resourceName": "YES",
"priorAdjustment": -0.2,
"originalNetAmount": -3135.5
}
],
"usageDate": "2026-10-07T08:41:42.00Z"
}
]
Get Usage with Adjustment and Settled Dispute Amounts
The following example retrieves usage records from the collection endpoint. The response illustrates adjustment and settled dispute amounts.
curl -X GET 'http://host:port/brm/usageManagement/v4/usage'
Response Body
The following example shows the contents of the response body in JSON format.
[
{
"@type": "Usage",
"billStructure": {
"id": "billing-account-strucuture-post-4"
},
"description": "Cycle Forward Fees (srvc): Standard GSM Telephony",
"adjustedAmount": {
"value": -3.0,
"unit": "EUR"
},
"endTime": "2026-10-07T07:28:06.00Z",
"id": "0.0.0.1+-event-billing-product-fee-cycle-cycle_forward_monthly+364738793259054626",
"href": "http://localhost:9090/brm/usageManagement/v5/usage/0.0.0.1+-event-billing-product-fee-cycle-cycle_forward_monthly+364738793259054626",
"taxAmount": {
"unit": "EUR",
"value": 0.0
},
"remainingAmount": {
"unit": "EUR",
"value": 37.548
},
"settledDisputeAmount": {
"unit": "EUR",
"value": -3.0
},
"discount": {
"unit": "EUR",
"value": 0.0
},
"billingAccount": {
"id": "0.0.0.1-158699"
},
"service": {
"id": "service-635"
},
"usageType": "/event/billing/product/fee/cycle/cycle_forward_monthly",
"cycleEnd": "2026-11-03T08:00:00.00Z",
"effectiveDate": "",
"rumName": "Occurrence",
"@baseType": "Usage",
"bill": {
"id": "0.0.0.1+-bill+364738793259034651"
},
"appliedCustomerBillingRate": {
"id": "0.0.0.1+-item-cycle_forward+364738793259055650"
},
"cycleStart": "2026-10-07T07:00:00.00Z",
"quantity": 1.0,
"@SchemaLocation": "",
"ratedProductUsage": [
{
"taxIncludedAmount": {
"unit": "EUR",
"value": 43.548
},
"taxExcludedAmount": {
"unit": "EUR",
"value": 43.548
},
"taxCode": "VAT",
"taxRate": 0.0
}
],
"nonCurrencyDetails": [
{
"resourceName": "YES",
"priorAdjustment": -0.2,
"originalNetAmount": -3135.5
}
],
"usageDate": "2026-10-07T07:28:06.00Z"
}
]
Get Rated Usage
The following example retrieves usage records from the collection endpoint. The response illustrates rated usage.
curl -X GET 'http://host:port/brm/usageManagement/v4/usage'
Response Body
The following example shows the contents of the response body in JSON format.
[
{
"@type": "Usage",
"bytesIn": 0,
"description": "/event/delayed/session/telco/gsm",
"endTime": "2026-10-07T09:40:00.00Z",
"id": "0.0.0.1+-event-delayed-session-telco-gsm+1517660297865925289",
"href": "http://localhost:9090/brm/usageManagement/v5/usage/0.0.0.1+-event-delayed-session-telco-gsm+1517660297865925289",
"taxAmount": {
"unit": "EUR",
"value": 0.0
},
"remainingAmount": {
"unit": "EUR",
"value": 66.406
},
"discount": {
"unit": "EUR",
"value": -8.594
},
"billingAccount": {
"id": "0.0.0.1-146670"
},
"service": {
"id": "Service-demo-2"
},
"cycleEnd": "",
"calledToNumber": "004941067600",
"effectiveDate": "",
"rumName": "DUR",
"@baseType": "Usage",
"bill": {
"id": "0.0.0.1+-bill+308426205730845166"
},
"appliedCustomerBillingRate": {
"id": "0.0.0.1+-item-misc+308426205730846878"
},
"cycleStart": "",
"quantity": 36000.0,
"@SchemaLocation": "",
"ratedProductUsage": [
{
"taxIncludedAmount": {
"unit": "EUR",
"value": 66.406
},
"taxExcludedAmount": {
"unit": "EUR",
"value": 66.406
}
}
],
"nonCurrencyDetails": [
{
"resourceName": "YES",
"originalNetAmount": 0.0
}
],
"bytesOut": 0,
"usageDate": "2026-10-06T23:40:00.00Z"
}
]